@@ -1,4 +1,4 @@
-def openapi(return_class=None, description=None, path_parameters=None, parameters=None):
+def openapi(return_class=None, description=None, path_parameters=None, parameters=None, body=None):
     def decorate(f):
         def wrapper(*args, **kwargs):
             if len(args) == 1:
@@ -7,7 +7,8 @@ def openapi(return_class=None, description=None, path_parameters=None, parameter
                         'return_class': return_class,
                         'description': description,
                         'path_parameters': path_parameters,
-                        "parameters": parameters
+                        "parameters": parameters,
+                        "body": body
                     }
             return f(*args, **kwargs)
         return wrapper
